import React from 'react';
import { View, Image, Button } from '@tarojs/components';
import { ActionSheet, Cell } from '@antmjs/vantui';
import { ROLES, ROLE_CITIZEN } from '@/utils/user';
import logo from '@/assets/image/logo.png';
import Icon from '@/assets/icons/avatar.png';
import { useModel } from '@/store';
import style from './head.module.less';

export default (props) => {
  const { user, person, duty, onDutyChange } = props;
  const { dutyList = [] } = user || {};
  const role = ROLES[duty || ROLE_CITIZEN];

  const [show, setShow] = React.useState(false);

  const [name, avatar] = React.useMemo(() => {
    return [
      user?.name || person?.name || '市民先生',
      user?.avatar || person?.avatar || logo,
    ];
  }, [user, person]);

  const actions = React.useMemo(() => {
    return dutyList.map(x => ({ name: ROLES[x], value: x }));
  }, [dutyList]);

  const onClick = () => {
    if (dutyList.length < 1) return;
    setShow(true);
  }

  const onSelect = (e) => {
    onDutyChange(e.detail.value)
  }

  const { getAvatar } = useModel('user');

  const onChooseAvatar = (e) => {
    const code = e.detail.code;
    getAvatar(code).then(props.onSuccess);
  }

  return (
    <View className={style.head}>
      <View className={style.profile}>
        <View style={{ letterSpacing: '2px' }}>Hi, {name}!</View>
        <View className={style.badge} onClick={onClick}>
          <View className={style.icon}>
            <Image src={Icon} />
          </View>
          <View>{role}</View>
        </View>
        <ActionSheet
          title="请选择身份"
          position="bottom"
          show={show}
          actions={actions}
          onClose={() => setShow(false)}
          onSelect={onSelect}
        />
      </View>
      <View className={style.avatar}>
        <Button openType="chooseAvatar" onChooseAvatar={onChooseAvatar}>
          <Image src={avatar}></Image>
        </Button>
      </View>
    </View>
  )
}
