import React from 'react';
import Page from '@/layouts/index';
import { Cell, CellGroup } from '@antmjs/vantui'
import { View } from '@tarojs/components';
// import * as echarts from "echarts"
import * as echarts from '@/assets/ec-canvas/echarts';
import './index.less';

export default (props) => {

  function initChart (canvas, width, height, dpr) {

    console.log('---------->', canvas, width, height)

    const chart = echarts.init(canvas, null, {
      width: width,
      height: height,
      devicePixelRatio: dpr // new
    });
    canvas.setChart(chart);

    var option = {
      title: {
        text: '上报统计'
      },
      grid: {
        left: '6%',
        right: '4%',
        bottom: '3%',
        width: '290px',
        containLabel: true
      },
      xAxis: [
        {
          type: 'category',
          boundaryGap: false,
          data: ['12/01', '12/02', '12/03', '12/04', '12/05', '12/06', '12/07']
        }
      ],
      yAxis: [
        {
          type: 'value',
          minInterval: 1
        }
      ],
      series: [
        {
          type: 'line',
          stack: 'Total',
          smooth: true,
          lineStyle: {
            width: 0
          },
          showSymbol: false,
          areaStyle: {
            opacity: 1,
            color: new echarts.graphic.LinearGradient(0, 0, 0, 1.1, [
              {
                offset: 0,
                color: '#0A9071'
              },
              {
                offset: 1,
                color: '#FFF'
              }
            ])
          },
          emphasis: {
            focus: 'series'
          },
          data: [1.8, 3.3, 1.9, 2.9, 2.1, 1.5, 2.3]
        }
      ]
    };

    chart.setOption(option);
    return chart;
  }

  const ec = {
    onInit: initChart
  };

  function initChart2 (canvas, width, height, dpr) {

    console.log('---------->', canvas, width, height)

    const chart = echarts.init(canvas, null, {
      width: width,
      height: height,
      devicePixelRatio: dpr // new
    });
    canvas.setChart(chart);

    var option = {
      title: {
        text: '交办统计'
      },
      grid: {
        left: '6%',
        bottom: '3%',
        width: '275px',
        containLabel: true
      },
      xAxis: [
        {
          type: 'category',
          boundaryGap: false,
          data: ['已处理', '未处理', '逾期'],
          boundaryGap: true,
          name: '状态',
          axisTick: {
            alignWithLabel: true,
          }
        }
      ],
      yAxis: [
        {
          type: 'value',
          minInterval: 1,
          name: '交办次数'
        }
      ],
      series: [
        {
          type: 'bar',
          barWidth: '15%',
          itemStyle: {
            color: new echarts.graphic.LinearGradient(0, 0, 0, 1, [
              { offset: 0, color: '#F772D1' },
              { offset: 0.5, color: '#C872F2' },
              { offset: 1, color: '#E5BEF8' }
            ])
          },
          data: [2, 3, 1]
        }
      ]
    };

    chart.setOption(option);
    return chart;
  }

  const ec2 = {
    onInit: initChart2
  };

  function initChart3 (canvas, width, height, dpr) {

    console.log('---------->', canvas, width, height)

    const chart = echarts.init(canvas, null, {
      width: width,
      height: height,
      devicePixelRatio: dpr // new
    });
    canvas.setChart(chart);

    var option = {
      title: {
        text: '问题分类'
      },
      grid: {
        left: '6%',
        right: '4%',
        bottom: '3%',
        width: '290px',
        containLabel: true
      },
      xAxis: [
        {
          type: 'category',
          boundaryGap: false,
          data: ['公益宣传', '环境卫生', '基础设施', '文明素养', '公共秩序', '其他'],
          boundaryGap: true,
          axisTick: {
            alignWithLabel: true,
          },
          axisLabel: {
            interval: 0,
            rotate: 40
          }
        }
      ],
      yAxis: [
        {
          type: 'value',
          minInterval: 1
        }
      ],
      series: [
        {
          type: 'bar',
          barWidth: '20%',
          itemStyle: {
            color: new echarts.graphic.LinearGradient(0, 0, 0, 1, [
              { offset: 0, color: '#FB9900' },
              { offset: 1, color: '#FFD38F' }
            ])
          },
          data: [2, 1, 2, 3, 2, 1]
        }
      ]
    };

    chart.setOption(option);
    return chart;
  }

  const ec3 = {
    onInit: initChart3
  };

  return (
    <Page>
      <View>
        <CellGroup>
          <Cell title="时间维度" isLink value="本周" />
        </CellGroup>
      </View>
      <view class="container">
        <ec-canvas canvasId="mychart-line" ec={ec}></ec-canvas>
      </view>
      <view class="container">
        <ec-canvas canvasId="mychart-bar" ec={ec2}></ec-canvas>
      </view>
      <view class="container">
        <ec-canvas canvasId="mychart-bar2" ec={ec3}></ec-canvas>
      </view>
    </Page>
  )
}